spm1d
=====

One-Dimensional <b>Statistical Parametric Mapping</b> in Python and MATLAB.
 
 
spm1d uses <b>Random Field Theory</b> expectations regarding the behavior of smooth, one-dimensional Gaussian fields to make statistical inferences regarding a set of one-dimensional continua.

Software documentation is hosted at:
[www.spm1d.org](http://spm1d.org)

Issues
------

Please report software bugs or other problems by searching existing issues or creating a new issue [here](https://github.com/0todd0000/spm1d/issues).

